#!/usr/bin/env python3
#   encoding: utf-8

# This is part of the Balladeer library.
# Copyright (C) 2024 D E Haynes

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import unittest

from balladeer import Presenter


class PresenterTests(unittest.TestCase):

    def test_sanitize_href(self):
        presenter = Presenter()
        for n, (html, spec) in enumerate([
            ('', ''),
            (
                '<a href="python.org">Python</a>',
                '<a href="python.org" target="_blank" rel="noopener noreferrer">Python</a>'
            ),
            (
                '<a href="python.org" target="_blank" rel="noopener noreferrer">Python</a>',
                '<a href="python.org" target="_blank" rel="noopener noreferrer">Python</a>'
            ),
        ]):
            with self.subTest(n=n):
                text = presenter.sanitize(html)
                self.assertEqual(text, spec)
